.. default-domain:: py

================================================
django-tables2 - An app for creating HTML tables
================================================

django-tables2 turns data into HTML tables. Features:

- Pagination
- Ordering
- Extendable
- Class based view
- Supports for queryset and list data
- Themes

Report bugs at http://github.com/bradleyayers/django-tables2/issues


.. toctree::
    :hidden:

    pages/tutorial
    pages/table-data
    pages/accessors
    pages/order-by-accessors
    pages/swapping-columns
    pages/column-headers
    pages/pagination
    pages/custom-rendering
    pages/query-string-fields	
    pages/column-attributes
    pages/builtin-columns
    pages/template-tags
    pages/template-filters
    pages/generic-mixins
    pages/table-mixins
    pages/tables-for-models
    pages/localization-control
    pages/api-reference
    pages/upgrading-from-v1
    pages/glossary
    pages/internal




